pub enum Error {
InvalidMove {
board: Board,
invalid_move: ChessMove,
},
InvalidFen {
fen: String,
},
InvalidSanMove,
InvalidSquare,
InvalidRank,
InvalidFile,
}Expand description
Error that can happen during the game.
derive from PartialEq for UnitTest
Variants
InvalidMove
The move on a particular board doesn’t respect the chess rules.
InvalidFen
Fields
fen: StringThe FEN (Forsyth-Edwards Notation) string is invalid.
InvalidSanMove
An attempt was made to create a move from an invalid SAN string.
InvalidSquare
An attempt was made to create a square from an invalid string.
InvalidRank
An attempt was made to convert a string not equal to “1”-“8” to a rank.
InvalidFile
An attempt was made to convert a string not equal to “a”-“h” to a file.