Struct chess::Button

source ·
pub struct Button {
    pub id: &'static str,
    /* private fields */
}
A struct of button for interact with the GUI.

Fields

id: &'static str

The id is not unique, it’s just a name to identify it.

Implementations

Create a new Button.

Verify if the button is enable.

Enable the button.

Disable the button.

Draw the image at the given path rather than a rectangle.

Verify if a coordinate is in the button.

Draw the button in the Context.

Call the func when the button is clicked.