Struct chess::ChessGui

source ·
pub struct ChessGui { /* private fields */ }
GUI for the Chess game.

Implementations

Create a new instance of ChessGui.

Reset The chess game and buttons but not the theme.

Set the theme for the GUI.

Examples
use chess::{ChessGui, THEME_SANDCASTLE};

let mut game = ChessGui::default();
game.set_theme(THEME_SANDCASTLE);

Set the theme to the next one for the GUI.

Safety

This function use/set a static variable.

Add a button in the GUI.

Base function to call when a user click on the screen.