MoveGen

Struct MoveGen 

pub struct MoveGen { /* private fields */ }
An incremental move generator

This structure enumerates moves slightly slower than board.enumerate_moves(…), but has some extra features, such as:

  • Being an iterator
  • Not requiring you to create a buffer
  • Only iterating moves that match a certain pattern
  • Being iterable multiple times (such as, iterating once for all captures, then iterating again for all quiets)
  • Doing as little work early on as possible, so that if you are not going to look at every move, the struture moves faster
  • Being able to iterate pseudo legal moves, while keeping the (nearly) free legality checks in place

Examples

use chess::MoveGen;
use chess::Board;
use chess::EMPTY;
use chess::construct;

// create a board with the initial position
let board = Board::default();

// create an iterable
let mut iterable = MoveGen::new_legal(&board);

// make sure .len() works.
assert_eq!(iterable.len(), 20); // the .len() function does *not* consume the iterator

// lets iterate over targets.
let targets = board.color_combined(!board.side_to_move());
iterable.set_iterator_mask(*targets);

// count the number of targets
let mut count = 0;
for _ in &mut iterable {
    count += 1;
    // This move captures one of my opponents pieces (with the exception of en passant)
}

// now, iterate over the rest of the moves
iterable.set_iterator_mask(!EMPTY);
for _ in &mut iterable {
    count += 1;
    // This move does not capture anything
}

// make sure it works
assert_eq!(count, 20);

Implementations

Source

impl MoveGen

Create a new MoveGen structure, only generating legal moves

pub fn remove_mask(&mut self, mask: BitBoard)

Never, ever, iterate any moves that land on the following squares

pub fn remove_move(&mut self, chess_move: ChessMove) -> bool

Never, ever, iterate this move

pub fn set_iterator_mask(&mut self, mask: BitBoard)

For now, Only iterate moves that land on the following squares Note: Once iteration is completed, you can pass in a mask of ! EMPTY to get the remaining moves, or another mask

pub fn legal_quick(board: &Board, chess_move: ChessMove) -> bool

This function checks the legality only for moves generated by MoveGen.

Calling this function for moves not generated by MoveGen will result in possibly incorrect results, and making that move on the Board will result in undefined behavior. This function may panic! if these rules are not followed.

If you are validating a move from a user, you should call the .legal() function.

pub fn movegen_perft_test(board: &Board, depth: usize) -> usize

Fastest perft test with this structure