Rust Chess Library

This is a chess library for rust with Gui.

Examples

use chess::{run, ChessGui};

fn main() {
    // Create and run the Gui game
    run(ChessGui::default());
}

Structs

A representation of a chess board that implement FEN notation (Board::from_str).

A struct of button for interact with the GUI.

A Standard Chess game.

GUI for the Chess game.

Represent a ChessMove in memory.

Describe the theme of the chess game (GUI).

Enums

Indicate how align the text (GUI).

What castle rights does a particular player have?

Represent a color in Chess game.

Describe 8 directions.

Sometimes, bad stuff happens.

Describe a file (column) on a chess board.

The Result of the game.

Represent a chess piece as a very simple enum.

Describe a rank (row) on a chess board.

Represent a square on the chess board.

Constants

List all colors.

Enumerate Direction in diagonal.

Enumerate all Direction.

Enumerate all files.

Enumerate Direction in line (vertical and horizontal).

An array representing each Piece type, in order of ascending value.

Enumerate all ranks.

Enumerate all Square.

The pixel-size of a Board’s cell.

The pixel-size of the board only (the board has a square form).

Number of cells in the Board.

Numbers of Color in chess game.

Numbers of diagonal.

Numbers of File.

Numbers of line (vertical and horizontal).

Numbers of Piece.

Numbers of Rank.

Numbers of Square.

Numbers of Theme.

The pixel-size of the screen.

The pixel-size of the side screen.

Enumerate all Theme.

Coral theme.

Dust theme.

Emerald theme.

Marine theme.

Sandcastle theme.

Wheat theme.

Functions

Run the GUI.