pub struct Chess { /* private fields */ }
A Standard Chess game.

TODO: Add a timer for each player.

Implementations

Create a new instance of Chess.

Get the history of the game.

The Vec contains a FEN-string.

Go back one step in history.

If the history is empty, reset the board to it’s default value.

Examples
use chess::{Chess, Square};
let mut chess = Chess::default();
let expected = Chess::default();
chess.play(Square::A2, Square::A4);
chess.undo();

assert_eq!(chess, expected);

Reset the Game (board and history).

Return the State of the Game.

Base function to call when a user click on the screen.

The current player offer a draw.

The offer is cancel when the player play.

Accept the draw. Assumes that a draw is offered.

Verify if a player can legally declare a draw by 3-fold repetition or 50-move rule.

Declare a draw by 3-fold repetition or 50-move rule. Assumes that a draw can be declare.

Color resigns the game.