pub struct Chess { /* private fields */ }
A Standard Chess game.
TODO: Add a timer for each player.
Create a new instance of Chess.
Get the history of the game.
The Vec contains a FEN-string.
Go back one step in history.
If the history is empty, reset the board to it’s default value.
use chess::{Chess, Square};
let mut chess = Chess::default();
let expected = Chess::default();
chess.play(Square::A2, Square::A4);
chess.undo();
assert_eq!(chess, expected);
Reset the Game (board and history).
Return the State of the Game
TODO: Verify here if we need the set the State to DrawByRequest or Resigns
Base function to call when a user click on the screen.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason. Read more
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,